==> psychosynth-0.1.2.tar.gz: psychosynth-0.1.2/psynth/version.hpp <==
/***************************************************************************
 *                                                                         *
 *   PSYCHOSYNTH                                                           *
 *   ===========                                                           *
 *                                                                         *
 *   Copyright (C) 2008 Juan Pedro Bolivar Puente                          *
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef PSYNTH_VERSION_H
#define PSYNTH_VERSION_H

#define PSYNTH_VERSION     "0.1.2"

#define PSYNTH_DATA_DIR    "./data"
#define PSYNTH_LIB_DIR     "/usr/local/lib"
#define PSYNTH_BIN_DIR     "/usr/local/bin"
#define PSYNTH_INCLUDE_DIR "/usr/local/include/libpsynth"

#if 1
#define PSYNTH_HAVE_ALSA 1
#endif

#if 1
#define PSYNTH_HAVE_OSS 1
#endif

#if 1
#define PSYNTH_HAVE_XML 1
#endif

#if 1
#define PSYNTH_HAVE_OSC 1
#endif

#if 1
#define PSYNTH_HAVE_PCM 1
#endif

#if 1
#define PSYNTH_HAVE_OGG 1
#endif

#if 1
#define PSYNTH_HAVE_JACK 1
#endif

#endif /* PSYNTH_VERSION_H */

==> psychosynth-0.1.3.tar.gz: psychosynth-0.1.3/psynth/version.hpp <==
/***************************************************************************
 *                                                                         *
 *   PSYCHOSYNTH                                                           *
 *   ===========                                                           *
 *                                                                         *
 *   Copyright (C) 2008 Juan Pedro Bolivar Puente                          *
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef PSYNTH_VERSION_H
#define PSYNTH_VERSION_H

#define PSYNTH_VERSION     "0.1.3"

#define PSYNTH_DATA_DIR    "/usr/local/share/psychosynth"
#define PSYNTH_LIB_DIR     "/usr/local/lib"
#define PSYNTH_BIN_DIR     "/usr/local/bin"
#define PSYNTH_INCLUDE_DIR "/usr/local/include/libpsynth"

#if 1
#define PSYNTH_HAVE_ALSA 1
#endif

#if 1
#define PSYNTH_HAVE_OSS 1
#endif

#if 1
#define PSYNTH_HAVE_XML 1
#endif

#if 1
#define PSYNTH_HAVE_OSC 1
#endif

#if 1
#define PSYNTH_HAVE_PCM 1
#endif

#if 1
#define PSYNTH_HAVE_OGG 1
#endif

#if 1
#define PSYNTH_HAVE_JACK 1
#endif

#endif /* PSYNTH_VERSION_H */
